import { Component, OnInit } from "@angular/core";
import { CapabilityRequest } from "../../model/capability-request";
import { CapabilityRequestService } from "../../services/capability-request.service";
import { JsonObject } from "@angular/compiler-cli/ngcc/src/packages/entry_point";
import { CapabilityLauncherService } from "../../services/capability-launcher.service";
import { WorkspacesComponent } from "../../workspaces.component";

@Component({
  selector: "app-list-of-calibratables",
  templateUrl: "./list-of-calibratables.component.html",
  styleUrls: ["./list-of-calibratables.component.scss"],
})
export class ListOfCalibratablesComponent implements OnInit {
  public calibratableRequests: Array<CapabilityRequest>;

  constructor(
    private capabilityRequestService: CapabilityRequestService,
    private capabilityLauncherService: CapabilityLauncherService,
  ) {}

  ngOnInit(): void {
    const createdRequestsObserver = {
      next: (request) => {
        this.calibratableRequests = request.created_requests;
      },
      error: (error) =>
        console.error("Error when retrieving list of created capability requests:" + error),
    };
    this.capabilityRequestService
      .getCreatedCapabilityRequests("std_calibration")
      .subscribe(createdRequestsObserver);
  }

  /**
   * Get metadata from capability request parameters if it exists
   * @param request Capability request
   * @return metadata Metadata section of parameters
   */
  public getMetadata(request: CapabilityRequest): any {
    if (request.parameters.hasOwnProperty("metadata")) {
      return request.parameters.metadata.valueOf();
    } else {
      return {};
    }
  }

  public submitRequest(id: string) {
    const submitCalibrationObservable = {
      next: (request) => {
        window.location.reload();
      },
      error: (error) => {
        console.error("Error when submitting calibration request:" + error);
      },
    };
    this.capabilityLauncherService.submit(id).subscribe(submitCalibrationObservable);
  }
}
